@@ -14,6 +14,47 @@ logger = logging.getLogger(__name__)
 TIMEZONE_BZ = ZoneInfo("America/Sao_Paulo")
 
 
+def _get_data(dates: pd.Series) -> pd.DataFrame:
+    """Busca dados de DI, incluindo dados intraday para o dia corrente se necessário."""
+    # 1. Busca inicial no cache com as datas solicitadas pelo usuário.
+    df_cached = (
+        get_cached_dataset("di1").query("TradeDate in @dates").reset_index(drop=True)
+    )
+
+    today = dt.now(TIMEZONE_BZ).date()
+    last_bday = bday.last_business_day().date()
+
+    # 2. Lógica para buscar dados intraday.
+    #    Isso é necessário quando o usuário solicita os dados do dia corrente
+    #    e eles ainda não foram persistidos no cache (processo noturno).
+    if (
+        # Condição 1: O dia de hoje foi explicitamente solicitado.
+        today in dates.values
+        # Condição 2: E ainda não está no cache.
+        and today not in df_cached["TradeDate"].values
+        # Condição 3: E hoje é o último dia útil.
+        and today == last_bday
+    ):
+        try:
+            df_intraday = b3.futures(contract_code="DI1", date=today)
+            if "SettlementPrice" not in df_intraday.columns or df_intraday.empty:
+                logger.warning(
+                    f"Ainda sem dados de ajustes intraday para {today}."
+                    " Retornando apenas dados do cache."
+                )
+                return df_cached
+            if "DaysToExp" in df_intraday.columns:
+                df_intraday.drop(columns=["DaysToExp"], inplace=True)
+            if df_cached.empty:
+                return df_intraday.reset_index(drop=True)
+            return pd.concat([df_cached, df_intraday]).reset_index(drop=True)
+        except Exception as e:
+            logger.error(f"Falha ao buscar dados intraday para {today}: {e}")
+
+    # 3. Se a lógica intraday não for acionada ou falhar, retorna apenas dados do cache.
+    return df_cached
+
+
 def data(
     dates: DateScalar | DateArray,
     month_start: bool = False,
@@ -57,22 +98,14 @@ def data(
     """
     dates = dc.convert_input_dates(dates)
     # Force dates to be a Series for consistency
-    dates = pd.Series(dates) if isinstance(dates, pd.Timestamp) else dates
+    if isinstance(dates, pd.Timestamp):
+        dates = pd.Series([dates]).astype("date32[pyarrow]")
+
     # Remove duplicates and sort dates
     dates = dates.drop_duplicates().sort_values().reset_index(drop=True)
-
-    df = get_cached_dataset("di1").query("TradeDate in @dates").reset_index(drop=True)
-
-    today = dt.now(TIMEZONE_BZ).date()
-    last_bday = bday.last_business_day()
-    is_trading_day = today == last_bday.date()
-    if is_trading_day and last_bday in df["TradeDate"]:
-        logger.info("Trying to get DI Futures data for today.")
-        df_intraday = b3.futures(contract_code="DI1", date=last_bday)
-        df = pd.concat([df, df_intraday]).reset_index(drop=True)
-
+    df = _get_data(dates)
     if df.empty:
-        logger.warning("No DI Futures data found for the specified dates.")
+        logger.warning("No DI1 data found for the specified dates.")
         logger.warning("Returning empty DataFrame.")
         return pd.DataFrame()
 
@@ -116,7 +149,7 @@ def data(
             return pd.DataFrame()
 
     if month_start:
-        df["ExpirationDate"] = df["ExpirationDate"].dt.to_period("M").dt.to_timestamp()
+        df["ExpirationDate"] = df["ExpirationDate"].dt.floor("MS")
 
     if not all_columns:
         cols = [
@@ -194,7 +227,7 @@ def interpolate_rates(
         0    0.13972
         1    0.134613
         2    <NA>
-        dtype: Float64
+        dtype: double[pyarrow]
 
         >>> # Interpolate rates for a single trade date and multiple expiration dates
         >>> # There is no DI Contract in 09-05-2025 with expiration 01-01-2050
@@ -206,7 +239,7 @@ def interpolate_rates(
         ... )
         0    0.13901
         1    0.13881
-        dtype: Float64
+        dtype: double[pyarrow]
 
         >>> # With extrapolation set to False, the second rate will be NaN
         >>> # Note: 0.13576348733268917 is shown as 0.135763
@@ -217,7 +250,7 @@ def interpolate_rates(
         ... )
         0    0.135763
         1    <NA>
-        dtype: Float64
+        dtype: double[pyarrow]
 
     Notes:
         - All available settlement rates are used for the flat-forward interpolation.
@@ -250,7 +283,7 @@ def interpolate_rates(
 
     # Initialize the interpolated rate column with NaN
     dfi["irate"] = pd.NA
-    dfi["irate"] = dfi["irate"].astype("Float64")
+    dfi["irate"] = dfi["irate"].astype("float64[pyarrow]")
 
     # Load DI rates dataset filtered by the provided reference dates
     dfr = data(dates=dates)
@@ -327,8 +360,8 @@ def interpolate_rate(
         >>> di1.interpolate_rate("25-04-2025", "01-01-2050", extrapolate=True)
         0.13881
     """
-    date = dc.convert_input_dates(date)
-    expiration = dc.convert_input_dates(expiration)
+    date = dc.convert_input_dates(date).date()
+    expiration = dc.convert_input_dates(expiration).date()
     if not date or not expiration:
         return float("NaN")
 
@@ -383,7 +416,7 @@ def eod_dates() -> pd.Series:
         2   1995-01-04
         3   1995-01-05
         4   1995-01-06
-        dtype: datetime64[ns]
+        dtype: date32[day][pyarrow]
     """
     available_dates = (
         get_cached_dataset("di1")
