@@ -36,22 +36,12 @@ def data(date: DateScalar) -> pd.DataFrame:
     Examples:
         >>> from pyield import ntnb
         >>> ntnb.data("23-08-2024")
-           ReferenceDate BondType MaturityDate  IndicativeRate        Price
-        0     2024-08-23    NTN-B   2025-05-15        0.063804  4377.008543
-        1     2024-08-23    NTN-B   2026-08-15        0.065795  4278.316344
-        2     2024-08-23    NTN-B   2027-05-15        0.063794   4350.54878
-        3     2024-08-23    NTN-B   2028-08-15        0.063094  4281.186307
-        4     2024-08-23    NTN-B   2029-05-15          0.0621  4358.101314
-        5     2024-08-23    NTN-B   2030-08-15        0.060298  4324.468801
-        6     2024-08-23    NTN-B   2032-08-15          0.0604  4320.153067
-        7     2024-08-23    NTN-B   2033-05-15        0.060403  4384.189924
-        8     2024-08-23    NTN-B   2035-05-15        0.060375  4386.002533
-        9     2024-08-23    NTN-B   2040-08-15        0.059797  4345.119587
-        10    2024-08-23    NTN-B   2045-05-15        0.060923  4358.235102
-        11    2024-08-23    NTN-B   2050-08-15         0.06114  4279.434119
-        12    2024-08-23    NTN-B   2055-05-15        0.060892  4355.145036
-        13    2024-08-23    NTN-B   2060-08-15        0.061005  4282.308398
-
+           ReferenceDate BondType  SelicCode  ...   AskRate IndicativeRate    DIRate
+        0     2024-08-23    NTN-B     760199  ...  0.063667       0.063804  0.112749
+        1     2024-08-23    NTN-B     760199  ...  0.065635       0.065795  0.114963
+        2     2024-08-23    NTN-B     760199  ...  0.063601       0.063794  0.114888
+        3     2024-08-23    NTN-B     760199  ...  0.062905       0.063094  0.115595
+        ...
     """
     return anbima.tpf_data(date, "NTN-B")
 
@@ -83,8 +73,7 @@ def maturities(date: DateScalar) -> pd.Series:
         11   2050-08-15
         12   2055-05-15
         13   2060-08-15
-        dtype: datetime64[ns]
-
+        dtype: date32[day][pyarrow]
     """
     df_rates = data(date)
     s_maturities = df_rates["MaturityDate"]
@@ -125,8 +114,8 @@ def _generate_all_coupon_dates(
     # First coupon date must be after the reference date, otherwise, it can lead to
     # division by zero where BDays == 0 (bootstrap method for instance)
     coupon_dates = coupon_dates[coupon_dates > start]
-
-    return pd.Series(coupon_dates).reset_index(drop=True)
+    coupon_dates = pd.Series(coupon_dates).astype("date32[pyarrow]")
+    return coupon_dates.reset_index(drop=True)
 
 
 def payment_dates(
@@ -153,7 +142,7 @@ def payment_dates(
         0   2024-05-15
         1   2024-11-15
         2   2025-05-15
-        dtype: datetime64[ns]
+        dtype: date32[day][pyarrow]
     """
     # Validate and normalize dates
     settlement = dc.convert_input_dates(settlement)
@@ -164,16 +153,17 @@ def payment_dates(
         raise ValueError("Maturity date must be after the start date.")
 
     # Initialize loop variables
-    coupon_dates = maturity
-    cp_dates = []
+    coupon_date = maturity
+    coupon_dates = []
 
     # Iterate backwards from the maturity date to the settlement date
-    while coupon_dates > settlement:
-        cp_dates.append(coupon_dates)
+    while coupon_date > settlement:
+        coupon_dates.append(coupon_date)
         # Move the coupon date back 6 months
-        coupon_dates -= pd.DateOffset(months=6)
+        coupon_date -= pd.DateOffset(months=6)
 
-    return pd.Series(cp_dates).sort_values(ignore_index=True)
+    coupon_dates = pd.Series(coupon_dates).astype("date32[pyarrow]")
+    return coupon_dates.sort_values().reset_index(drop=True)
 
 
 def cash_flows(
@@ -410,8 +400,8 @@ def spot_rates(
         df.at[index, "SpotRate"] = price_factor ** (1 / row["BYears"]) - 1
 
     df = df[["MaturityDate", "BDToMat", "SpotRate"]].copy()
-    # Force Float64 type in float columns to standardize the output
-    df["SpotRate"] = df["SpotRate"].astype("Float64")
+    # Force float64 type in float columns to standardize the output
+    df["SpotRate"] = df["SpotRate"].astype("float64[pyarrow]")
 
     # Filter the result without the intermediate coupon dates (virtual bonds)
     if not show_coupons:
@@ -506,7 +496,7 @@ def bei_rates(
         extrapolate=True,
     )
 
-    df["NIR"] = df["BDToMat"].apply(nir_interplator).astype("Float64")
+    df["NIR"] = df["BDToMat"].apply(nir_interplator).astype("float64[pyarrow]")
     # Calculate Breakeven Inflation Rate (BEI)
     df["BEI"] = ((df["NIR"] + 1) / (df["RIR"] + 1)) - 1
 
