@@ -52,9 +52,10 @@ def data(date: DateScalar) -> pd.DataFrame:
 
     Examples:
         >>> from pyield import ntnc
-        >>> ntnc.data("21-03-2025")
-          ReferenceDate BondType MaturityDate  IndicativeRate        Price
-        0    2025-03-21    NTN-C   2031-01-01        0.067626  8347.348705
+        >>> ntnc.data("23-08-2024")
+          ReferenceDate BondType  SelicCode  ...   AskRate IndicativeRate   DIRate
+        0    2024-08-23    NTN-C     770100  ...  0.057587       0.059617  0.11575
+        ...
     """
     return anbima.tpf_data(date, "NTN-C")
 
@@ -90,7 +91,7 @@ def payment_dates(
         9    2030-01-01
         10   2030-07-01
         11   2031-01-01
-        dtype: datetime64[ns]
+        dtype: date32[day][pyarrow]
     """
     # Validate and normalize dates
     settlement = dc.convert_input_dates(settlement)
@@ -101,16 +102,17 @@ def payment_dates(
         raise ValueError("Maturity date must be after the start date.")
 
     # Initialize loop variables
-    coupon_dates = maturity
-    cp_dates = []
+    coupon_date = maturity
+    coupon_dates = []
 
     # Iterate backwards from the maturity date to the settlement date
-    while coupon_dates > settlement:
-        cp_dates.append(coupon_dates)
+    while coupon_date > settlement:
+        coupon_dates.append(coupon_date)
         # Move the coupon date back 6 months
-        coupon_dates -= pd.DateOffset(months=6)
+        coupon_date -= pd.DateOffset(months=6)
 
-    return pd.Series(cp_dates).sort_values(ignore_index=True)
+    coupon_dates = pd.Series(coupon_dates).astype("date32[pyarrow]")
+    return coupon_dates.sort_values().reset_index(drop=True)
 
 
 def cash_flows(
