@@ -36,13 +36,12 @@ def data(date: DateScalar) -> pd.DataFrame:
     Examples:
         >>> from pyield import ntnf
         >>> ntnf.data("23-08-2024")
-          ReferenceDate BondType MaturityDate  IndicativeRate        Price
-        0    2024-08-23    NTN-F   2025-01-01        0.107692  1011.189166
-        1    2024-08-23    NTN-F   2027-01-01        0.115109   985.834842
-        2    2024-08-23    NTN-F   2029-01-01        0.116337   964.126325
-        3    2024-08-23    NTN-F   2031-01-01        0.117008   945.416939
-        4    2024-08-23    NTN-F   2033-01-01        0.116307   934.776692
-        5    2024-08-23    NTN-F   2035-01-01        0.116586   923.239406
+          ReferenceDate BondType  SelicCode  ...   AskRate IndicativeRate   DIRate
+        0    2024-08-23    NTN-F     950199  ...  0.107524       0.107692  0.10823
+        1    2024-08-23    NTN-F     950199  ...  0.114948       0.115109  0.11467
+        2    2024-08-23    NTN-F     950199  ...   0.11621       0.116337   0.1156
+        3    2024-08-23    NTN-F     950199  ...  0.116958       0.117008  0.11575
+        ...
     """
     return anbima.tpf_data(date, "NTN-F")
 
@@ -66,7 +65,7 @@ def maturities(date: DateScalar) -> pd.Series:
         3   2031-01-01
         4   2033-01-01
         5   2035-01-01
-        dtype: datetime64[ns]
+        dtype: date32[day][pyarrow]
     """
     df_rates = data(date)
     s_maturities = df_rates["MaturityDate"]
@@ -111,7 +110,7 @@ def payment_dates(
         >>> ntnf.payment_dates("15-05-2024", "01-01-2025")
         0   2024-07-01
         1   2025-01-01
-        dtype: datetime64[ns]
+        dtype: date32[day][pyarrow]
     """
     # Validate and normalize dates
     settlement = dc.convert_input_dates(settlement)
@@ -135,7 +134,8 @@ def payment_dates(
         coupon_date -= pd.DateOffset(months=6)
 
     # Return the coupon dates as a sorted Series
-    return pd.Series(coupon_dates).sort_values(ignore_index=True)
+    coupon_dates = pd.Series(coupon_dates).astype("date32[pyarrow]")
+    return coupon_dates.sort_values().reset_index(drop=True)
 
 
 def cash_flows(
@@ -276,7 +276,7 @@ def spot_rates(  # noqa
         5   2035-01-01     2587  0.121398
     """
     # Process and validate the input data
-    settlement = dc.convert_input_dates(settlement)
+    settlement = dc.convert_input_dates(settlement).date()
 
     # Create flat forward interpolators for LTN and NTN-F rates
     ltn_rate_interpolator = ip.Interpolator(
@@ -321,7 +321,7 @@ def spot_rates(  # noqa
         df.at[index, "SpotRate"] = price_factor ** (1 / row["BYears"]) - 1
 
     df = df[["MaturityDate", "BDToMat", "SpotRate"]].copy()
-    df["SpotRate"] = df["SpotRate"].astype("Float64")
+    df["SpotRate"] = df["SpotRate"].astype("float64[pyarrow]")
 
     if not show_coupons:
         df = df.query("MaturityDate in @ntnf_maturities").reset_index(drop=True)
